@@ -33,9 +33,8 @@ class TestCase:
             function(*args, **kwargs)
         except exception:
             return
-        raise AssertionError("{} failed to raise {}"
-                             .format(repr(function),
-                                     repr(exception)))
+        raise AssertionError("{} failed to raise {}".format(
+            repr(function), repr(exception)))
 
     def get_sample_text(self, format, name=None):
         """
